========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/oslo.messaging.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

Oslo Messaging Library
======================

.. image:: https://img.shields.io/pypi/v/oslo.messaging.svg
    :target: https://pypi.org/project/oslo.messaging/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.messaging.svg
    :target: https://pypi.org/project/oslo.messaging/
    :alt: Downloads

The Oslo messaging API supports RPC and notifications over a number of
different messaging transports.

* License: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/oslo.messaging/latest/
* Source: https://opendev.org/openstack/oslo.messaging
* Bugs: https://bugs.launchpad.net/oslo.messaging
* Release notes: https://docs.openstack.org/releasenotes/oslo.messaging/
